@@ -1,8 +1,8 @@
 from django.contrib.syndication.views import Feed
 from django.core.urlresolvers import reverse
-from blogger.models import Post
-from taggit.models import Tag
 from django.utils.translation import ugettext_lazy as _
+from taggit.models import Tag
+from .models import Post
 
 
 class LatestEntriesFeed(Feed):
