@@ -1,5 +1,6 @@
+from django.template.defaultfilters import slugify
 from rest_framework import serializers
-from blogger.models import Post, Author
+from .models import Post, Author
 
 
 class PostSerializer(serializers.HyperlinkedModelSerializer):
@@ -16,19 +17,22 @@ class PostSerializer(serializers.HyperlinkedModelSerializer):
 
     def restore_object(self, attrs, instance=None):
         if instance is not None:
-            instance.author = attrs['author']
+            # author is controlled by the view
             instance.title = attrs['title']
             instance.body = attrs['body']
             instance.published = attrs['published']
-            #instance.tags = attrs['tags']
-            instance.slug = attrs['slug']
+            # TODO: assign tags from json data
+            # tags = [tag.trim() for tag in attrs['tags'].split(',')]
+            # instance.tags.set(tags)
+            instance.slug = slugify(attrs['title'])
             return instance
         return Post(**attrs)
 
 
 class AuthorSerializer(serializers.HyperlinkedModelSerializer):
     """Serializes the Author model"""
+    posts = serializers.ManyHyperlinkedRelatedField(source='post_set', view_name='post-detail')
 
     class Meta:
         model = Author
-        fields = ('url', 'first_name', 'last_name')
+        fields = ('url', 'username','first_name', 'last_name', 'posts')
